@@ -15,7 +15,7 @@ CODEC_REGISTRY: Dict[str, abc.Partitioning] = {}
 
 
 def get_codecs(config: Dict) -> abc.Partitioning:
-    """Get the partitioning scheme for the given configuration
+    """Get the partitioning scheme for the given configuration.
 
     Args:
         config: A dictionary of the partitioning configuration parameters.
@@ -26,12 +26,12 @@ def get_codecs(config: Dict) -> abc.Partitioning:
     Raises:
         ValueError: If the requested codec is not defined.
     """
-    codec_id = config.pop("id", None)
+    codec_id = config.pop('id', None)
     if codec_id is None:
-        raise ValueError(f"codec not available: {codec_id!r}")
+        raise ValueError(f'codec not available: {codec_id!r}')
     cls = CODEC_REGISTRY.get(codec_id, None)
     if cls is None:
-        raise ValueError(f"codec not available: {codec_id!r}")
+        raise ValueError(f'codec not available: {codec_id!r}')
     return cls.from_config(config)
 
 
@@ -48,5 +48,5 @@ def register_codec(cls, codec_id=None) -> None:
     if codec_id is None:
         codec_id = cls.ID
     if codec_id in CODEC_REGISTRY:
-        raise ValueError(f"codec already registered: {codec_id!r}")
+        raise ValueError(f'codec already registered: {codec_id!r}')
     CODEC_REGISTRY[codec_id] = cls
